summaryrefslogtreecommitdiff
path: root/chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h')
-rw-r--r--chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h b/chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h
index 4c517e14fbb..9fa239bacc2 100644
--- a/chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h
+++ b/chromium/third_party/blink/renderer/core/css/cssom/computed_style_property_map.h
@@ -8,7 +8,7 @@
#include "base/macros.h"
#include "third_party/blink/renderer/core/css/css_computed_style_declaration.h"
#include "third_party/blink/renderer/core/css/css_selector.h"
-#include "third_party/blink/renderer/core/css/cssom/style_property_map_read_only.h"
+#include "third_party/blink/renderer/core/css/cssom/style_property_map_read_only_main_thread.h"
#include "third_party/blink/renderer/core/dom/node.h"
namespace blink {
@@ -17,11 +17,13 @@ namespace blink {
// API. The specification is here:
// https://drafts.css-houdini.org/css-typed-om/#computed-StylePropertyMapReadOnly-objects
//
-// The computed StylePropertyMapReadOnly retrieves computed styles and returns
-// them as CSSStyleValues. The IDL for this class is in StylePropertyMap.idl.
-// The computed StylePropertyMapReadOnly for an element is accessed via
-// element.computedStyleMap() (see ElementComputedStyleMap.idl/h)
-class CORE_EXPORT ComputedStylePropertyMap : public StylePropertyMapReadOnly {
+// The computed StylePropertyMapReadOnlyMainThread retrieves computed styles and
+// returns them as CSSStyleValues. The IDL for this class is in
+// StylePropertyMap.idl. The computed StylePropertyMapReadOnlyMainThread for an
+// element is accessed via element.computedStyleMap() (see
+// ElementComputedStyleMap.idl/h)
+class CORE_EXPORT ComputedStylePropertyMap
+ : public StylePropertyMapReadOnlyMainThread {
public:
static ComputedStylePropertyMap* Create(Node* node) {
return new ComputedStylePropertyMap(node);
@@ -29,7 +31,7 @@ class CORE_EXPORT ComputedStylePropertyMap : public StylePropertyMapReadOnly {
void Trace(blink::Visitor* visitor) override {
visitor->Trace(node_);
- StylePropertyMapReadOnly::Trace(visitor);
+ StylePropertyMapReadOnlyMainThread::Trace(visitor);
}
unsigned int size() override;
@@ -41,7 +43,7 @@ class CORE_EXPORT ComputedStylePropertyMap : public StylePropertyMapReadOnly {
protected:
ComputedStylePropertyMap(Node* node, const String& pseudo_element = String())
- : StylePropertyMapReadOnly(),
+ : StylePropertyMapReadOnlyMainThread(),
pseudo_id_(CSSSelector::ParsePseudoId(pseudo_element)),
node_(node) {}